function [count, label] = nbm_gen(wght, alpha, beta, T)

%nbm_gen   Simulates data from a negative binomial mixture.
%          Use: [count,label] = nbm_gen(wght,alpha,beta,T) where
%          count is an array of length T which contains the simulated
%          data and label contains the corresponding simulated mixture
%          indicators.
%          Requires Matlab's Statistics toolbox or GNU Octave.

% H2M/cnt Toolbox, $Revision: 2.2 $
% Olivier Capp, 2004/02/06 - $Date: 2004/03/15 14:02:47 $
% http://www.tsi.enst.fr/~cappe/h2m/

% Needed functions
if (~((exist('randindx') == 2) | (exist('randindx') == 3)))
  error('Function randindx (from h2m toolbox) is missing.');
end

% Check that we have something to simulate from Poisson and Gamma
if ((exist('poisson_rnd') == 2) & (exist('gamma_rnd') == 2))
  S_VER = 0; % Octave
elseif ((exist('poissrnd') == 2) & (exist('gamrnd') == 2))
  S_VER = 1; % Matlab + statistics toolbox
else
  error(['Either poissrnd, gamrnd (Matlab''s Statistics toolbox)\n'...
         'or poisson_rnd, gamma_rnd (Octave > 2.0.14) are required\n' ...
	 '(but read the H2M doc to see how to get around the problem).']);
end

% Inputs arguments
error(nargchk(4, 4, nargin));
N = nbm_chk(wght, alpha, beta);
% Make sure that the output will be a column vector
alpha = reshape(alpha, N, 1);
beta = reshape(beta, N, 1);

% First simulate labels
label = randindx(wght, T);

% First draw the rates, then the Poisson data
if (S_VER == 0)
  rate = gamma_rnd(alpha(label), beta(label));
  count = poisson_rnd(rate); 
else
  % Beware, Matlab Statistics toolbox use a non-standard
  % inverted convention for the scale parameter
  rate = gamrnd(alpha(label), 1./beta(label));
  count = poissrnd(rate);
end
