%ex_1d     A simple 1 Dimensional Gaussian HMM example (3 states)
%	Beware : This is not a real demo, so you should take a look at the
%       source file before executing it if you want to understand what's
%       going on! The graphical part will probably not work under octave.

% H2M Toolbox, $Revision: 2.3 $        
% O. Cappe, 27/11/2001 - $Date: 2004/11/03 14:19:34 $
% http://www.tsi.enst.fr/~cappe/h2m/

clear;

% Constant: Flags for diagonal and full covariance matrices
FULL_COV = 0;
DIAG_COV = 1;

% Data generation
p = 1;
N = 3;
T = 250;
n_it = 10;
pi0_sim = ones(1,N)/N;
A_sim = [0.9 0.07 0.03; 0.05 0.8 0.15; 0.1 0.05 0.85];
mu_sim = [1; 1.1; -1];
Sigma_sim = [0.1; 0.03; 0.2];
X = hmm_gen(A_sim, pi0_sim, mu_sim, Sigma_sim, T);
% Initialization values
pi0 = pi0_sim;
A = A_sim;
mu = [0.5; 1.5; -2];
Sigma = 0.2*ones(N,p);
% EM iterations
for i = 1:n_it
  [alpha, beta, logl_tmp, dens] = hmm_fb(X, A, pi0, mu, Sigma);
  logl(i) = logl_tmp;
  [A, pi0] = hmm_tran(alpha, beta, dens, A, pi0);
  [mu, Sigma] = hmm_dens(X, alpha, beta, DIAG_COV); % FULL_COV would be
                                                      % the same here since
                                                      % we are 1-D
end

% Plot data and classifcation
figure(1);
clf;
subplot(1+N,1,1);
plot(X);
gamma = alpha .* beta;
gamma = gamma ./ (sum(gamma')' * ones(1,N));
for i=1:N
  subplot(1+N,1,1+i);
  stem(gamma(:,i));
  title(['State ' int2str(i)]);
end;

% Plot histogram with estimated marginal distribution
figure(2);
clf;
t = linspace(min(X), max(X), 60)';
dens = gauseval(t, mu, Sigma);
[nn,xx] = hist(X, t);
bar(xx, nn*(t(2)-t(1)), 1);
colormap(cool);
hold on;
w = statdis(A)';
for i = 1:N
  h = plot(t, dens(:,i)*w(i), '--r');
  set(h, 'LineWidth', 2);
end
h= plot(t, dens*w, 'r');
set(h, 'LineWidth', 2);
