function [A, pi0, mu, Sigma, logl] = hmm (X, A_ini, pi0_ini, mu_ini, Sigma_ini, n_it)

%hmm       Performs multiple iterations of the EM algorithm.
%	   This is just a call to the lower-level functions.
%       Use: [A,pi0,mu,Sigma,logl] = hmm(X,A_ini,pi0_ini,mu_ini,Sigma_ini,n_it)

% H2M Toolbox, $Revision: 2.3 $        
% Olivier Capp, 07/02/97 - $Date: 2004/11/03 14:19:34 $
% http://www.tsi.enst.fr/~cappe/h2m/

% Turn verbose mode off
QUIET = 1;
% Check input data and dimensions
error(nargchk(6, 6, nargin));
% Check that the initialization value are correct
[N, p, DIAG_COV] = hmm_chk(A_ini, pi0_ini, mu_ini, Sigma_ini);
% Check size of training data
[T,v] = size(X);
if (v ~= p)
  error('Size of training data is incorrect.');
end 
% Use supplied values as initialization
A = A_ini;
pi0 = pi0_ini;
mu = mu_ini;
Sigma = Sigma_ini;

logl = zeros(1,n_it);
for i = 1:n_it
  [alpha, beta, logl_tmp, dens] = hmm_fb(X, A, pi0, mu, Sigma, QUIET);
  logl(i) = logl_tmp;
  [A, pi0] = hmm_tran(alpha, beta, dens, A, pi0, QUIET);
  [mu, Sigma] = hmm_dens(X, alpha, beta, DIAG_COV, QUIET);
  fprintf(1, 'Iteration %d:\t%.3f\n', i, logl(i));
end
